/**********************************************************************************
 Two compartment partial volume correction for brain PET image analysis, using
 FreeSurfer generated ROIs, based on a two component model, i.e. brain tissue and
 others (including background, csf, which are assumed to have no signal).
  
 USAGE:
 PVC2CFS FSfile PETMASK fsROIlist fwhm
 FSfile is the 4dfp file of the freesurfer segmentation output, typically 
 wmparc001.4dfp.img; PETMASK is a 4dfp file that specifies the PET field of view to
 make sure PET ROI analysis contains only voxels that are within PET FOV. fsROIlist
 is a two column text file that specifies the ROI name and value corresponding to
 the FreeSurferColorLUT.txt file that contains all the defined regions in the FSfile.
 It is generated by some preprocessing step.
 The output file has the name PVC2CFS.txt, that has three columns. The first column is
 the ROI label and the second column is the recovery coefficient, which should be
 used as the denominator to correct for partial volume effects based on two 
 component mode. The third column is the roi size within PET FOV, in case regions
 need to be merged after the generation of this output. 

 Yi Su, 03/16/2011
**********************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <stdbool.h>
#include <string.h>
#include <math.h>
#include <time.h>
#include <endianio.h>
#include <Getifh.h>
#include <rec.h>
#include <librms.h>
#include <nrutil.h>
#include <RSF.h>

int main(int argc, char **argv)
{
	int i, j, nvroi[16384], m2, vallist[16384], nroi, nx, ny, nz, tmp;
	float *fptr1, *fptr2, *fptr3, cmppix[3], fhalf, pvc[16384];
	IMAGE_4dfp *FSdata=NULL, *PETMask=NULL, *mask=NULL;
	FILE *fp;
	char **fsregions = NULL;
	char optf[MAXL], tmpstr[MAXL], line[512];

	/* read FSdata, PETMask */
	FSdata=read_image_4dfp(argv[1], FSdata);
	PETMask=read_image_4dfp(argv[2], PETMask);
	
	/* read roi list */
	fsregions = (char **)malloc((size_t)((16384)*sizeof(char *)));
	if (!fsregions) errm("PVC2CFS");
	
	fp = fopen(argv[3],"r");
	if (!fp) errr("PVC2CFS",argv[3]);
	j=0;
	while (fgets(line, 512, fp)){
		sscanf(line, "%s%d", tmpstr, vallist+j);
		fsregions[j]=(char *)malloc((size_t)(MAXL*sizeof(char)));
		if (!fsregions[j]) errm("PVC2CFS");
		strcpy(fsregions[j], tmpstr);
		j++;  
	}
	nroi=j;
	fclose(fp);
	printf("Done...Read ROI List\n");
	
	/* allocate memory for mask */
	m2=FSdata->ifh.number_of_bytes_per_pixel*FSdata->ifh.matrix_size[0]*FSdata->ifh.matrix_size[1]*FSdata->ifh.matrix_size[2]*FSdata->ifh.matrix_size[3];
	mask=(IMAGE_4dfp *)malloc((size_t)sizeof(IMAGE_4dfp));
	if (!mask) errm("PVC2CFS");
	mask->image=(float *)malloc((size_t)m2);
	if (!mask->image) errm("PVC2CFS");	
	m2=m2/FSdata->ifh.number_of_bytes_per_pixel;
	
	/* create binary mask that defines brain tissue against CSF and background */
	fptr1=FSdata->image;
	fptr2=mask->image;
	tmp=0;
	for (i=0; i<m2; i++)
	{
		if ( (int)(*fptr1)==0 || (int)(*fptr1)==4  || (int)(*fptr1)==5  || 
		    (int)(*fptr1)==14 || (int)(*fptr1)==15 || (int)(*fptr1)==30 ||
		    (int)(*fptr1)==43 || (int)(*fptr1)==44 || (int)(*fptr1)==62 ||
		    (int)(*fptr1)==72 || (int)(*fptr1)==73 || (int)(*fptr1)==74 ||
		    (int)(*fptr1)==75 || (int)(*fptr1)==76 || (int)(*fptr1)==24 ||
		    (int)(*fptr1)==98 || ((int)(*fptr1)>=118 && (int)(*fptr1)<=158) ||
		    (int)(*fptr1)==165 || (int)(*fptr1)==166 || (int)(*fptr1)==167 ||
		    (int)(*fptr1)==168 || ((int)(*fptr1)>=169 && (int)(*fptr1)<=215) ||
		    (int)(*fptr1)==217 || (int)(*fptr1)==221 || (int)(*fptr1)== 224 ||
		    ((int)(*fptr1)>=256 && (int)(*fptr1)<=499) || 
		    ((int)(*fptr1)>=559 && (int)(*fptr1)<=701) ||
		    ((int)(*fptr1)>=704 && (int)(*fptr1)<=999)) {
		    *fptr2=0;
		    }
		else {
		    *fptr2=1;
		    tmp++;
		    }
		fptr1++;
		fptr2++;
	}
	printf("%d\n",tmp);
	printf("Done...Binarize FS mask\n");

	/* convolve binary brain mask with gaussian kernel */
	fhalf = 4.412712/atof(argv[4]); /* argv[4] is the fwhm of the gaussian kernal in mm */
	nx = FSdata->ifh.matrix_size[0];
	ny = FSdata->ifh.matrix_size[1];
	nz = FSdata->ifh.matrix_size[2];
	cmppix[0]=FSdata->ifh.scaling_factor[0]/10.;
	cmppix[1]=FSdata->ifh.scaling_factor[1]/10.;
	cmppix[2]=FSdata->ifh.scaling_factor[2]/10.;
	printf("%f;%d;%d;%d;%f,%f,%f\n",fhalf, nx, ny, nz, cmppix[0], cmppix[1], cmppix[2]);
	gauss3d(mask->image, &nx, &ny, &nz, cmppix, &fhalf);

	printf("Done...blurr brain mask\n");
	
	/* calculate regional correction factor */
	fptr1=mask->image;
	fptr2=FSdata->image;
	fptr3=PETMask->image;
	for (i=0; i<nroi; i++) {
		pvc[i]=0;
		nvroi[i]=0;
		
	}
	for (i=0; i<m2; i++) {
		if (*fptr3>0) {
			for (j=0; j<nroi; j++){
				if ((int)(*fptr2)==vallist[j]) {
					pvc[j]+=*fptr1;
					nvroi[j]++;
				}
			}
		}
		fptr1++;
		fptr2++;
		fptr3++;
		
	}
	printf("Done...calculating correction factor\n");
	
	/* print output */
	if (!(fp = fopen("PVC2CFS.txt","w"))) errw("PVC2CFS", "PVC2CFS.txt");
	for (i=0; i<nroi; i++) {
		pvc[i]=pvc[i]/(float)nvroi[i];
		fprintf(fp, "%-35s%10.4f%10d\n", fsregions[i], pvc[i], nvroi[i]);
		free(fsregions[i]);
	}
	
	printf("Done...print output\n");
	
	free(fsregions);
	fclose(fp);
	free(mask->image);
	free(mask);
	
	return 0;
}
